"""
Copyright 2023-2023 VMware Inc.
SPDX-License-Identifier: Apache-2.0

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
    http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

import click
from hcs_core.ctxp import recent

from hcs_cli.service.lcm import provider


@click.command()
@click.argument("id", type=str, required=False)
def delete(id: str):
    """Delete provider by ID"""
    id = recent.require("provider", id)
    ret = provider.delete(id)

    # trick
    if ret is True:  # found
        return
    if ret is None:  # not found
        return

    return ret, 1
